@@ -9,6 +9,7 @@
 #include <QInputDialog>
 #include <QUrl>
 #include <wctype.h>
+#include <sys/stat.h>
 
 #include "obs-frontend-api.h"
 #include "obs-module.h"
@@ -21,9 +22,13 @@ OBS_DECLARE_MODULE()
 OBS_MODULE_AUTHOR("Exeldro");
 OBS_MODULE_USE_DEFAULT_LOCALE("scene-collection-manager", "en-US")
 
+#define MAX_PATH 260
+
 static obs_hotkey_id sceneCollectionManagerDialog_hotkey_id =
 	OBS_INVALID_HOTKEY_ID;
 static obs_hotkey_id backup_hotkey_id = OBS_INVALID_HOTKEY_ID;
+static obs_hotkey_id load_last_backup_hotkey_id = OBS_INVALID_HOTKEY_ID;
+static obs_hotkey_id load_first_backup_hotkey_id = OBS_INVALID_HOTKEY_ID;
 SceneCollectionManagerDialog *sceneCollectionManagerDialog = nullptr;
 
 static bool autoSaveBackup = false;
@@ -139,25 +144,17 @@ void BackupSceneCollectionHotkey(void *data, obs_hotkey_id id,
 	BackupSceneCollection();
 }
 
-std::string GetFilenameFromPath(std::string path)
+std::string GetFilenameFromPath(std::string path, bool with_extension)
 {
-	const auto slash = path.find_last_of('/');
-	const auto backslash = path.find_last_of('\\');
-	if (slash != std::string::npos && backslash != std::string::npos) {
-		if (slash > backslash) {
-			path = path.substr(slash + 1);
-		} else {
-			path = path.substr(backslash + 1);
-		}
-	} else if (slash != std::string::npos) {
+	const auto slash = path.find_last_of("/\\");
+	if (slash != std::string::npos) {
 		path = path.substr(slash + 1);
-	} else if (backslash != std::string::npos) {
-		path = path.substr(backslash + 1);
 	}
-
-	const auto point = path.find_last_of('.');
-	if (point != std::string::npos) {
-		path = path.substr(0, point);
+	if (!with_extension) {
+		const auto point = path.find_last_of('.');
+		if (point != std::string::npos) {
+			path = path.substr(0, point);
+		}
 	}
 	return path;
 }
@@ -172,7 +169,7 @@ std::string GetBackupDirectory(std::string filename)
 		}
 		return filename;
 	}
-	filename = GetFilenameFromPath(filename);
+	filename = GetFilenameFromPath(filename, false);
 	std::string dir = customBackupDir;
 
 	if (dir.back() != '/' && dir.back() != '\\')
@@ -182,6 +179,108 @@ std::string GetBackupDirectory(std::string filename)
 	return dir;
 }
 
+void LoadBackupSceneCollection(const std::string sceneCollection,
+			       const std::string filename,
+			       const std::string backupFile)
+{
+	if (!filename.length())
+		return;
+
+	const auto backupDir = GetBackupDirectory(filename);
+	auto *data = obs_data_create_from_json_file(backupFile.c_str());
+	obs_data_set_string(data, "name", sceneCollection.c_str());
+	obs_data_save_json_safe(data, filename.c_str(), "tmp", "bak");
+	obs_data_release(data);
+	if (strcmp(obs_frontend_get_current_scene_collection(),
+		   sceneCollection.c_str()) == 0) {
+		config_set_string(obs_frontend_get_global_config(), "Basic",
+				  "SceneCollection", "");
+		config_set_string(obs_frontend_get_global_config(), "Basic",
+				  "SceneCollectionFile",
+				  "scene_collection_manager_temp");
+		obs_frontend_set_current_scene_collection(
+			sceneCollection.c_str());
+		std::string path = obs_module_config_path(
+			"../../basic/scenes/scene_collection_manager_temp.json");
+		os_unlink(path.c_str());
+	} else {
+		obs_frontend_set_current_scene_collection(
+			sceneCollection.c_str());
+	}
+}
+
+void LoadBackupSceneCollection(bool last)
+{
+	const auto config = obs_frontend_get_global_config();
+	if (!config)
+		return;
+	const std::string sceneCollection =
+		config_get_string(config, "Basic", "SceneCollection");
+	const std::string filename =
+		config_get_string(config, "Basic", "SceneCollectionFile");
+	std::string path = obs_module_config_path("../../basic/scenes/");
+	path += filename;
+	path += ".json";
+
+	const auto backupDir = GetBackupDirectory(path);
+	const auto f = backupDir + "*.json";
+	os_glob_t *glob;
+	if (os_glob(f.c_str(), 0, &glob) != 0) {
+		return;
+	}
+	std::string backupFile;
+	time_t time = 0;
+	for (size_t i = 0; i < glob->gl_pathc; i++) {
+		const char *filePath = glob->gl_pathv[i].path;
+
+		if (glob->gl_pathv[i].directory)
+			continue;
+
+		struct stat stats {
+		};
+		if (os_stat(filePath, &stats) == 0 && stats.st_size > 0) {
+			if (last) {
+				if (time == 0 || stats.st_ctime >= time) {
+					backupFile = filePath;
+					time = stats.st_ctime;
+				}
+			} else {
+				if (time == 0 || stats.st_ctime <= time) {
+					backupFile = filePath;
+					time = stats.st_ctime;
+				}
+			}
+		}
+	}
+	os_globfree(glob);
+	if (time != 0)
+		LoadBackupSceneCollection(sceneCollection, path, backupFile);
+}
+
+void LoadLastBackupSceneCollectionHotkey(void *data, obs_hotkey_id id,
+					 obs_hotkey_t *hotkey, bool pressed)
+{
+	if (!pressed)
+		return;
+	const auto main =
+		static_cast<QMainWindow *>(obs_frontend_get_main_window());
+	QMetaObject::invokeMethod(
+		main, [] { LoadBackupSceneCollection(true); },
+		Qt::QueuedConnection);
+}
+
+void LoadFirstBackupSceneCollectionHotkey(void *data, obs_hotkey_id id,
+					  obs_hotkey_t *hotkey, bool pressed)
+{
+	if (!pressed)
+		return;
+	const auto main =
+		static_cast<QMainWindow *>(obs_frontend_get_main_window());
+	QMetaObject::invokeMethod(
+		main, [] { LoadBackupSceneCollection(false); },
+		Qt::QueuedConnection);
+}
+
 static void frontend_event(obs_frontend_event event, void *)
 {
 	if (event == OBS_FRONTEND_EVENT_EXIT) {
@@ -195,6 +294,15 @@ static void frontend_event(obs_frontend_event event, void *)
 		obs_data_set_array(save_data, "backupHotkey",
 				   hotkey_save_array);
 		obs_data_array_release(hotkey_save_array);
+		hotkey_save_array = obs_hotkey_save(load_last_backup_hotkey_id);
+		obs_data_set_array(save_data, "loadLastBackupHotkey",
+				   hotkey_save_array);
+		obs_data_array_release(hotkey_save_array);
+		hotkey_save_array =
+			obs_hotkey_save(load_first_backup_hotkey_id);
+		obs_data_set_array(save_data, "loadFirstBackupHotkey",
+				   hotkey_save_array);
+		obs_data_array_release(hotkey_save_array);
 		auto d = obs_data_get_json(save_data);
 		const QByteArray data(d);
 		config_set_string(obs_frontend_get_global_config(),
@@ -229,6 +337,16 @@ bool obs_module_load()
 		obs_module_text("BackupSceneCollection"),
 		BackupSceneCollectionHotkey, nullptr);
 
+	load_last_backup_hotkey_id = obs_hotkey_register_frontend(
+		"load_last_backup_scene_collection",
+		obs_module_text("LoadLastBackupSceneCollection"),
+		LoadLastBackupSceneCollectionHotkey, nullptr);
+
+	load_first_backup_hotkey_id = obs_hotkey_register_frontend(
+		"load_first_backup_scene_collection",
+		obs_module_text("LoadFirstBackupSceneCollection"),
+		LoadFirstBackupSceneCollectionHotkey, nullptr);
+
 	auto config = obs_frontend_get_global_config();
 	autoSaveBackup = config_get_bool(config, "SceneCollectionManager",
 					 "AutoSaveBackup");
@@ -254,6 +372,18 @@ bool obs_module_load()
 			obs_hotkey_load(backup_hotkey_id, hotkey_save_array);
 			obs_data_array_release(hotkey_save_array);
 
+			hotkey_save_array = obs_data_get_array(
+				save_data, "loadLastBackupHotkey");
+			obs_hotkey_load(load_last_backup_hotkey_id,
+					hotkey_save_array);
+			obs_data_array_release(hotkey_save_array);
+
+			hotkey_save_array = obs_data_get_array(
+				save_data, "loadFirstBackupHotkey");
+			obs_hotkey_load(load_first_backup_hotkey_id,
+					hotkey_save_array);
+			obs_data_array_release(hotkey_save_array);
+
 			obs_data_release(save_data);
 		}
 	}
@@ -270,6 +400,8 @@ void obs_module_unload()
 	obs_frontend_remove_save_callback(frontend_save_load, nullptr);
 	obs_hotkey_unregister(sceneCollectionManagerDialog_hotkey_id);
 	obs_hotkey_unregister(backup_hotkey_id);
+	obs_hotkey_unregister(load_first_backup_hotkey_id);
+	obs_hotkey_unregister(load_last_backup_hotkey_id);
 }
 
 MODULE_EXPORT const char *obs_module_description(void)
@@ -314,7 +446,9 @@ void SceneCollectionManagerDialog::on_actionAddSceneCollection_triggered()
 	auto a = m.addAction(QString::fromUtf8(obs_module_text("New")));
 	connect(a, SIGNAL(triggered()), this,
 		SLOT(on_actionAddNewSceneCollection_triggered()));
-	//m.addAction(QString::fromUtf8(obs_module_text("Import")));
+	a = m.addAction(QString::fromUtf8(obs_module_text("Import")));
+	connect(a, SIGNAL(triggered()), this,
+		SLOT(on_actionImportSceneCollection_triggered()));
 	a = m.addAction(QString::fromUtf8(obs_module_text("Duplicate")));
 	connect(a, SIGNAL(triggered()), this,
 		SLOT(on_actionDuplicateSceneCollection_triggered()));
@@ -326,6 +460,301 @@ void SceneCollectionManagerDialog::on_actionAddNewSceneCollection_triggered()
 	obs_frontend_add_scene_collection("");
 }
 
+void SceneCollectionManagerDialog::on_actionImportSceneCollection_triggered()
+{
+	auto files = QFileDialog::getOpenFileNames(
+		this, obs_module_text("ImportSceneCollection"), "",
+		"Scene Collection (*.json)");
+	if (files.isEmpty())
+		return;
+	auto path_buffer = (char *)bmalloc(MAX_PATH);
+	auto scene_collections_ = scene_collections;
+	for (auto file : files) {
+
+		auto fu = file.toUtf8();
+
+		auto data = obs_data_create_from_json_file(fu.constData());
+		if (!data)
+			continue;
+
+		auto name = obs_data_get_string(data, "name");
+		auto n = QString::fromUtf8(name);
+
+		bool replace_current = false;
+		if (scene_collections_.count(n) > 0) {
+			//TODO ask if replace
+			auto sc = obs_frontend_get_current_scene_collection();
+			if (strcmp(sc, name) == 0) {
+				replace_current = true;
+			} else {
+			}
+		} else {
+			if (!obs_frontend_add_scene_collection(name)) {
+				obs_data_release(data);
+				continue;
+			}
+			replace_current = true;
+		}
+		std::string safeName;
+		if (!GetFileSafeName(name, safeName)) {
+			obs_data_release(data);
+			continue;
+		}
+		std::string dir = fu.constData();
+		std::size_t slash = dir.find_last_of("/\\");
+		if (slash != std::string::npos) {
+			auto point = dir.find_last_of('.');
+			if (point != std::string::npos && point > slash) {
+				dir = dir.substr(0, point);
+				dir += "/";
+				try_fix_paths(data, dir.c_str(), path_buffer);
+			}
+			dir = dir.substr(0, slash + 1);
+		}
+		try_fix_paths(data, dir.c_str(), path_buffer);
+
+		std::string path =
+			obs_module_config_path("../../basic/scenes/");
+		path += safeName;
+		path += ".json";
+		obs_data_save_json_safe(data, path.c_str(), "tmp", "bak");
+
+		if (replace_current) {
+			config_set_string(obs_frontend_get_global_config(),
+					  "Basic", "SceneCollection", "");
+			config_set_string(obs_frontend_get_global_config(),
+					  "Basic", "SceneCollectionFile",
+					  "scene_collection_manager_temp");
+
+			obs_frontend_set_current_scene_collection(name);
+			std::string tempPath = ""; //path;
+			tempPath += "scene_collection_manager_temp.json";
+			os_unlink(tempPath.c_str());
+		}
+		obs_data_release(data);
+		BackupSceneCollection();
+	}
+	bfree(path_buffer);
+}
+
+static bool replace(std::string &str, const char *from, const char *to)
+{
+	size_t start_pos = str.find(from);
+	if (start_pos == std::string::npos)
+		return false;
+	str.replace(start_pos, strlen(from), to);
+	return true;
+}
+
+void SceneCollectionManagerDialog::try_fix_paths(obs_data_t *data,
+						 const char *dir,
+						 char *path_buffer)
+{
+	obs_data_item_t *item = obs_data_first(data);
+	while (item) {
+		const enum obs_data_type type = obs_data_item_gettype(item);
+		if (type == OBS_DATA_STRING) {
+			std::string str = obs_data_item_get_string(item);
+			bool edit = false;
+			if (replace(str, "[U_COMBOBULATOR_PATH]", dir)) {
+				obs_data_item_set_string(&item, str.c_str());
+				edit = true;
+			}
+			bool local_url = false;
+			if (str.substr(0, 7) == "file://") {
+				str = str.substr(7);
+				local_url = true;
+			}
+			std::size_t found = str.find_last_of("/\\");
+			if (found != std::string::npos &&
+			    !os_file_exists(str.c_str())) {
+				while (found != std::string::npos) {
+					auto file =
+						found == 0 && str[0] != '/' &&
+								str[0] != '\\'
+							? str
+							: str.substr(found + 1);
+					if (file.find('.') == std::string::npos)
+						break;
+					auto oldDir = str.substr(0, found + 1);
+					std::string newFile = dir;
+					newFile += file;
+					if (os_file_exists(newFile.c_str())) {
+						if (local_url) {
+							str = "file://";
+							if (os_get_abs_path(
+								    newFile.c_str(),
+								    path_buffer,
+								    MAX_PATH)) {
+								for (auto i = 0;
+								     path_buffer
+									     [i] !=
+								     '\0';
+								     i++)
+									if (path_buffer
+										    [i] ==
+									    '\\')
+										path_buffer[i] =
+											'/';
+								str += path_buffer;
+							}
+						} else {
+							if (os_get_abs_path(
+								    newFile.c_str(),
+								    path_buffer,
+								    MAX_PATH)) {
+								for (auto i = 0;
+								     path_buffer
+									     [i] !=
+								     '\0';
+								     i++)
+									if (path_buffer
+										    [i] ==
+									    '\\')
+										path_buffer[i] =
+											'/';
+								str = path_buffer;
+							} else {
+								str = "";
+							}
+						}
+						obs_data_item_set_string(
+							&item, str.c_str());
+						edit = true;
+						break;
+					}
+					if (found == 0) {
+						found = std::string::npos;
+					} else {
+						found = str.find_last_of(
+							"/\\", found - 1);
+						if (found ==
+						    std::string::npos) {
+							found = 0;
+						}
+					}
+				}
+			}
+			if (edit) {
+				item = obs_data_first(data);
+				continue;
+			}
+		} else if (type == OBS_DATA_OBJECT) {
+			if (obs_data_t *obj = obs_data_item_get_obj(item)) {
+				try_fix_paths(obj, dir, path_buffer);
+				obs_data_release(obj);
+			}
+		} else if (type == OBS_DATA_ARRAY) {
+			const auto array = obs_data_item_get_array(item);
+			const auto count = obs_data_array_count(array);
+			for (size_t i = 0; i < count; i++) {
+				if (obs_data_t *obj =
+					    obs_data_array_item(array, i)) {
+					try_fix_paths(obj, dir, path_buffer);
+					obs_data_release(obj);
+				}
+			}
+		}
+		obs_data_item_next(&item);
+	}
+}
+
+void SceneCollectionManagerDialog::export_local_files(obs_data_t *data,
+						      std::string dir,
+						      std::string subdir)
+{
+	obs_data_item_t *item = obs_data_first(data);
+	while (item) {
+		const enum obs_data_type type = obs_data_item_gettype(item);
+		if (type == OBS_DATA_STRING) {
+			std::string str = obs_data_item_get_string(item);
+			bool local_url = false;
+			if (str.substr(0, 7) == "file://") {
+				str = str.substr(7);
+				local_url = true;
+			}
+			auto slash = str.find('\\');
+			while (slash != std::string::npos) {
+				str.replace(slash, slash + 1, "/");
+				slash = str.find('\\');
+			}
+			std::size_t found = str.find_last_of("/\\");
+			if (found != std::string::npos &&
+			    os_file_exists(str.c_str()) &&
+			    (str.length() < dir.length() ||
+			     str.substr(0, dir.length()) != dir)) {
+				//todo move file to dir and update item
+				auto filename = GetFilenameFromPath(str, true);
+				std::string newDir = subdir;
+				std::string safe;
+				auto n = obs_data_item_get_name(item);
+				if (n && GetFileSafeName(n, safe)) {
+					newDir += safe;
+					newDir += "/";
+				}
+				auto fullNewDir = dir + newDir;
+				os_mkdirs(fullNewDir.c_str());
+				auto newFile = fullNewDir + filename;
+				if (os_file_exists(newFile.c_str())) {
+					os_unlink(newFile.c_str());
+				}
+				if (os_copyfile(str.c_str(), newFile.c_str()) ==
+				    0) {
+					newFile = newDir + filename;
+					if (local_url) {
+						str = "file://";
+						str += newFile.c_str();
+					} else {
+						str = newFile.c_str();
+					}
+					obs_data_item_set_string(&item,
+								 str.c_str());
+					item = obs_data_first(data);
+					continue;
+				}
+			}
+		} else if (type == OBS_DATA_OBJECT) {
+			if (obs_data_t *obj = obs_data_item_get_obj(item)) {
+				std::string newDir = subdir;
+				std::string safe;
+				auto n = obs_data_item_get_name(item);
+				if (n && GetFileSafeName(n, safe)) {
+					newDir += safe;
+					newDir += "/";
+				}
+				export_local_files(obj, dir, newDir);
+				obs_data_release(obj);
+			}
+		} else if (type == OBS_DATA_ARRAY) {
+			std::string newDir = dir;
+			newDir += obs_data_item_get_name(item);
+			newDir += "/";
+			const auto array = obs_data_item_get_array(item);
+			const auto count = obs_data_array_count(array);
+			for (size_t i = 0; i < count; i++) {
+				if (obs_data_t *obj =
+					    obs_data_array_item(array, i)) {
+					std::string newDir = subdir;
+					std::string safe;
+					auto n = obs_data_item_get_name(item);
+					if (n && GetFileSafeName(n, safe)) {
+						newDir += safe;
+						newDir += "/";
+					}
+					n = obs_data_get_string(obj, "name");
+					if (n && GetFileSafeName(n, safe)) {
+						newDir += safe;
+						newDir += "/";
+					}
+					export_local_files(obj, dir, newDir);
+					obs_data_release(obj);
+				}
+			}
+		}
+		obs_data_item_next(&item);
+	}
+}
+
 void SceneCollectionManagerDialog::on_actionDuplicateSceneCollection_triggered()
 {
 	if (const auto item = ui->sceneCollectionList->currentItem()) {
@@ -419,7 +848,9 @@ void SceneCollectionManagerDialog::on_actionConfigSceneCollection_triggered()
 	auto a = m.addAction(QString::fromUtf8(obs_module_text("Rename")));
 	connect(a, SIGNAL(triggered()), this,
 		SLOT(on_actionRenameSceneCollection_triggered()));
-	//m.addAction(QString::fromUtf8(obs_module_text("Export")));
+	a = m.addAction(QString::fromUtf8(obs_module_text("Export")));
+	connect(a, SIGNAL(triggered()), this,
+		SLOT(on_actionExportSceneCollection_triggered()));
 	m.exec(QCursor::pos());
 }
 
@@ -484,6 +915,44 @@ void SceneCollectionManagerDialog::on_actionRenameSceneCollection_triggered()
 	}
 }
 
+void SceneCollectionManagerDialog::on_actionExportSceneCollection_triggered()
+{
+	const auto item = ui->sceneCollectionList->currentItem();
+	if (!item)
+		return;
+	const auto filename = scene_collections.at(item->text());
+	if (!filename.length())
+		return;
+	const QString file = QFileDialog::getSaveFileName(
+		this, obs_module_text("ExportSceneCollection"), "",
+		"Scene Collection (*.json)");
+	if (file.isEmpty())
+		return;
+
+	auto data =
+		obs_data_create_from_json_file_safe(filename.c_str(), "bak");
+	auto f = file.toUtf8();
+	std::string dir = f.constData();
+	auto slash = dir.find_last_of("/\\");
+	if (slash != std::string::npos) {
+		auto point = dir.find_last_of('.');
+		if (point != std::string::npos && point > slash) {
+			dir = dir.substr(0, point);
+			dir += "/";
+		} else {
+			dir = dir.substr(0, slash + 1);
+		}
+	}
+	slash = dir.find('\\');
+	while (slash != std::string::npos) {
+		dir.replace(slash, slash + 1, "/");
+		slash = dir.find('\\');
+	}
+	export_local_files(data, dir, "");
+	obs_data_save_json(data, f.constData());
+	obs_data_release(data);
+}
+
 void SceneCollectionManagerDialog::on_actionSwitchSceneCollection_triggered()
 {
 	if (const auto item = ui->sceneCollectionList->currentItem()) {
@@ -599,11 +1068,16 @@ void SceneCollectionManagerDialog::on_actionConfigBackup_triggered()
 		m.addMenu(QString::fromUtf8(obs_module_text("BackupDir")));
 	a = dirMenu->addAction(QString::fromUtf8(obs_module_text("ShowDir")));
 	connect(a, &QAction::triggered, [] {
-		const QUrl url = QUrl::fromLocalFile(QString::fromUtf8(
-			customBackupDir.empty()
-				? os_get_abs_path_ptr(obs_module_config_path(
-					  "../../basic/scenes/"))
-				: customBackupDir.c_str()));
+		QUrl url;
+		if (customBackupDir.empty()) {
+			auto ptr = os_get_abs_path_ptr(
+				obs_module_config_path("../../basic/scenes/"));
+			url = QUrl::fromLocalFile(QString::fromUtf8(ptr));
+			bfree(ptr);
+		} else {
+			url = QUrl::fromLocalFile(
+				QString::fromUtf8(customBackupDir.c_str()));
+		}
 		QDesktopServices::openUrl(url);
 	});
 
@@ -714,32 +1188,9 @@ void SceneCollectionManagerDialog::on_actionSwitchBackup_triggered()
 				return;
 
 			const auto backupFile = backupDir + safeName + ".json";
-			auto *data = obs_data_create_from_json_file(
-				backupFile.c_str());
-			obs_data_set_string(data, "name",
-					    item->text().toUtf8().constData());
-			obs_data_save_json_safe(data, filename.c_str(), "tmp",
-						"bak");
-			obs_data_release(data);
-			const QString currentSceneCollection = QString::fromUtf8(
-				obs_frontend_get_current_scene_collection());
-			if (currentSceneCollection == item->text()) {
-				config_set_string(
-					obs_frontend_get_global_config(),
-					"Basic", "SceneCollection", "");
-				config_set_string(
-					obs_frontend_get_global_config(),
-					"Basic", "SceneCollectionFile",
-					"scene_collection_manager_temp");
-				obs_frontend_set_current_scene_collection(
-					item->text().toUtf8().constData());
-				std::string path = obs_module_config_path(
-					"../../basic/scenes/scene_collection_manager_temp.json");
-				os_unlink(path.c_str());
-			} else {
-				obs_frontend_set_current_scene_collection(
-					item->text().toUtf8().constData());
-			}
+			LoadBackupSceneCollection(
+				item->text().toUtf8().constData(), filename,
+				backupFile);
 		}
 	}
 }
@@ -779,6 +1230,7 @@ void SceneCollectionManagerDialog::on_sceneCollectionList_currentRowChanged(
 			ui->backupList->addItem(
 				QString::fromUtf8(name.c_str()));
 		}
+		os_globfree(glob);
 	}
 }
 
@@ -826,6 +1278,7 @@ void SceneCollectionManagerDialog::ReadSceneCollections()
 		}
 		scene_collections[QString::fromUtf8(name.c_str())] = filePath;
 	}
+	os_globfree(glob);
 }
 
 SceneCollectionManagerDialog::SceneCollectionManagerDialog(QMainWindow *parent)
